aboutsummaryrefslogtreecommitdiffstats
path: root/config/hypr/initial-boot.sh
diff options
context:
space:
mode:
authorJaKooLit <jimmielovejay@gmail.com>2023-12-07 14:29:10 +0900
committerJaKooLit <jimmielovejay@gmail.com>2023-12-07 14:29:10 +0900
commitabb68d82a2a839438a3de19b377084ae9796bf42 (patch)
tree3e3b79a8e0b6df9d0782d0f14c00d3dcec704893 /config/hypr/initial-boot.sh
parent91515c96c89e22cc8411279a6263740f897ba6ca (diff)
updated initial boot and kb layout switch
Diffstat (limited to 'config/hypr/initial-boot.sh')
-rwxr-xr-xconfig/hypr/initial-boot.sh36
1 files changed, 22 insertions, 14 deletions
diff --git a/config/hypr/initial-boot.sh b/config/hypr/initial-boot.sh
index cfadfcc4..797f49cb 100755
--- a/config/hypr/initial-boot.sh
+++ b/config/hypr/initial-boot.sh
@@ -1,11 +1,12 @@
#!/bin/bash
-# A bash script designed to ran it only once dotfiles installed
+# A bash script designed to run only once dotfiles installed
# THIS SCRIPT CAN BE DELETED ONCE SUCCESSFULLY BOOTED!! And also, edit ~/.config/hypr/configs/Execs.conf
-# not necessary to do since this script is only designed to ran only once as long as the marker exist
+# not necessary to do since this script is only designed to run only once as long as the marker exists
-# Set swww options
+# Variables
+scriptsDir=$HOME/.config/hypr/scripts
wallpaper=$HOME/Pictures/wallpapers/anime-girl-abyss.png
swww="swww img"
@@ -14,18 +15,25 @@ effect="--transition-bezier .43,1.19,1,.4 --transition-fps 60 --transition-type
# Check if a marker file exists.
if [ ! -f ~/.config/hypr/.initial_startup_done ]; then
- # Initialize pywal
- printf " Initializing pywal........\n\n"
- wal -i $wallpaper
+ # Initialize pywal
+ printf " Initializing pywal........\n\n"
+ wal -i "$wallpaper"
+
+ # Initial symlink for Pywal Dark and Light for Rofi Themes
+ ln -sf "$HOME/.cache/wal/colors-rofi-dark.rasi" "$HOME/.config/rofi/pywal-color/pywal-theme.rasi"
+
+ # Initial scripts to load in order to have a proper wallpaper waybar and pywal themes
+ pkill swww && swww init || swww query && $swww "$wallpaper" $effect
+
+ # Refreshing waybar, dunst, rofi etc.
+ "$scriptsDir/PywalSwww.sh" > /dev/null 2>&1 &
+ "$scriptsDir/Refresh.sh" > /dev/null 2>&1 &
+
+ # initiate the kb_layout (for some reason) waybar cant launch it
+ "$scriptsDir/SwitchKeyboardLayout.sh" > /dev/null 2>&1 &
- #initial symlink for Pywal Dark and Light for Rofi Themes
- ln -sf "$HOME/.cache/wal/colors-rofi-dark.rasi" "$HOME/.config/rofi/pywal-color/pywal-theme.rasi"
-
- # Initial scripts to load inorder to have a proper wallpaper waybar and pywal themes
- swww query || swww init && $swww $wallpaper $effect
-
# Create a marker file to indicate that the script has been executed.
touch ~/.config/hypr/.initial_startup_done
-fi
-
+ exit
+fi
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage